from typing import Optional

from .identifier import StatuteID


def rule_translate(text: str) -> Optional[tuple[str, str]]:
    if (
        "Professional Responsibility" in text
        or "CPR" in text
        or "C.P.R" in text
    ):
        return "RULE_ROC", "professional-responsibility"
    elif "Judicial Ethics" in text:
        return "RULE_ROC", "judicial-ethics"
    elif "Professional Ethics" in text:
        return "RULE_ROC", "professional-ethics"
    elif "1940 Rules of Court" in text:
        return "RULE_ROC", "1940"
    elif "1964 Rules of Court" in text:
        return "RULE_ROC", "1964"
    return None


def code_translate(text: str) -> Optional[tuple[str, str]]:
    if "Spanish" in text:
        if idx := StatuteID.SPAIN.get_spanish_id_code(text):
            return "SPAIN", idx
    elif "Old" in text or "old" in text or "Code of Commerce" in text:
        if idx := StatuteID.SPAIN.get_spanish_id_code(text):
            return "SPAIN", idx
    elif "Code of Professional Responsibility" in text:
        return "RULE_ROC", "professional-responsibility"
    elif "Civil Code" in text:
        return "RA", "386"
    elif (
        "Administrative Code of 1917" in text
        or "Revised Administrative Code of 1917" in text
    ):
        return "ACT", "2711"
    elif (
        "revised Corporation Code" in text
        or "Revised Corporation Code" in text
    ):
        return "RA", "11232"
    elif "Corporation Code" in text:
        return "BP", "68"
    elif "Code of Civil Procedure" in text:
        return "ACT", "190"
    elif "Penal Code" in text or "RPC" in text or "R.P.C." in text:
        return "ACT", "3815"
    elif "Labor Code" in text:
        return "PD", "442"
    elif "Child and Youth" in text:
        return "PD", "603"
    elif "Family" in text:
        return "EO", "209"
    elif "Revised Administrative Code" in text:
        return "ACT", "2711"
    elif "Administrative Code" in text:
        return "EO", "292"
    elif "Intellectual Property" in text:
        return "RA", "8293"
    elif "Local Government" in text or "LGC" in text or "L.G.C." in text:
        return "RA", "7160"
    return None
