from typing import Iterator, Optional

from .matcher import MatchedTitleProvision, compiler


def get_single_formal_title(
    text: str,
) -> Optional[tuple[Optional[str], Optional[str]]]:
    """Return titled Statute and provision from first title found."""
    return (x.statute_id, x.provision) if (x := single_match(text)) else None


def get_single_cat_idx(text: str) -> Optional[tuple[str, str]]:
    """Return category and identifier from first title found."""
    return x.cat_idx if (x := single_match(text)) and x.is_statutory else None


def single_match(text: str) -> Optional[MatchedTitleProvision]:
    """Get first title / provision combination, if existing"""
    return res[0] if (res := compiler(text)) and len(res) == 1 else None


def single_search_query(raw: str) -> Optional[MatchedTitleProvision]:
    """Enables catching of queries starting with lowercased titles, e.g. 'ra 386'"""
    return x if (x := single_match(raw.upper()) or single_match(raw)) else None


def extract_cat_idx_all_titles(
    text: str,
) -> Optional[Iterator[tuple[str, str]]]:
    if not (compiled := compiler(text)):
        return None
    for c in compiled:
        if c.is_statutory:
            yield c.cat_idx
