from .base import StatutePatternsMethods


class RepublicAct(StatutePatternsMethods):
    def __init__(self) -> None:
        base_text = self.statute_base_pattern(
            group_name="republic_act",
            first_word=r"Rep(.|ublic)?",
            second_word=r"Act?\s?",
            first_letter="R",
            second_letter="A",
            optional_number_keyword=self.optional_number_keyword,
        )

        digit = rf"(?P<RA_digit>{self.digit_format})"

        self.formula = rf"""
        ( # e.g. Republic Act (RA) No. 242
            \b{base_text}
            \s*{digit}
        )
        """


class ExecutiveOrder(StatutePatternsMethods):
    def __init__(self) -> None:
        base_text = self.statute_base_pattern(
            group_name="executive_order",
            first_word=r"Exec(.|utive)?",
            second_word=r"Order?\s?",
            first_letter="E",
            second_letter="O",
            optional_number_keyword=self.optional_number_keyword,
        )

        digit = rf"(?P<EO_digit>{self.digit_format})"

        self.formula = rf"""
        (
            \b{base_text}
            \s*{digit}
        )
        """


class PresidentialDecree(StatutePatternsMethods):
    def __init__(self) -> None:
        base_text = self.statute_base_pattern(
            group_name="presidential_decree",
            first_word=r"Pres(.|idential)?",
            second_word=r"Dec(.|ree)?\s?",
            first_letter="P",
            second_letter="D",
            optional_number_keyword=self.optional_number_keyword,
        )

        digit = rf"(?P<PD_digit>{self.digit_format})"

        self.formula = rf"""
        (
            \b{base_text}
            \s*{digit}
        )
        """


class BatasPambansa(StatutePatternsMethods):
    def __init__(self) -> None:
        base_text = self.statute_base_pattern(
            group_name="batas_pambansa",
            first_word=r"Batas",
            second_word=r"Pambansa",
            first_letter="B",
            second_letter="P",
            optional_number_keyword=self.optional_bilang_keyword,
        )  # * number keyword replaced with bilang

        digit = rf"(?P<BP_digit>{self.digit_format})"

        self.formula = rf"""
        (
            \b{base_text}
            \s*{digit}
        )
        """


class CommonwealthAct(StatutePatternsMethods):

    group_name = "commonwealth_act"
    category = "CA"

    def __init__(self) -> None:
        base_text = self.statute_base_pattern(
            group_name="commonwealth_act",
            first_word=r"Com(.|monwealth)?",
            second_word=r"Act\s?",
            first_letter="C",
            second_letter="A",
            optional_number_keyword=self.optional_number_keyword,
        )

        # * digits are limited to 3
        digit = rf"(?P<CA_digit>{self.simple_commonwealth_digits})"

        self.formula = rf"""
        (
            \b{base_text}
            \s*{digit}
        )
        """


class LegacyAct(StatutePatternsMethods):
    def __init__(self) -> None:

        # join a list of negative lookbehinds
        non_match = "".join(
            rf"(?<!{i}\s)"
            for i in [
                r"An",
                r"AN",
                r"Republic",
                r"Rep",
                r"Rep\.",
                r"REPUBLIC",
                r"Commonwealth",
                r"COMMONWEALTH",
            ]
        )

        # * negative lookbehinds with words: "Act/Acts"
        base_text = rf"(?P<legacy_act>{non_match}Acts?)"

        digit = rf"(?P<ACT_digit>{self.digit_format})"

        self.formula = rf"""
        (
            \b{base_text}
            \s+{self.optional_number_keyword}
            \s*{digit}
        )
        """
