class LegalCode:
    special_acronyms = r"""
    (
        (
            LGC\b|
            L\.G\.C\.|
            1997\s+NIRC\b| # national internal revenue code 1997
            1977\s+NIRC\b| # national internal revenue code 1977
            1939\s+NIRC\b| # national internal revenue code 1939
            NIRC\b| # national internal revenue code
            N\.I\.R\.C\.|
            RPC\b| # revised penal code
            R\.P\.C\.|
            OEC\b # omnibus election code
        )
    )
    """

    capitalized_text = r"""
    (
        (
            [A-Z] # first letter capitalized
            [a-z]* # zero or many small letters
        )
        \s* # since the word might be
    )+
    """

    code_at_start = r"""
    (
        \b
        Code
        \s+
        of
        \s+
    )
    """

    code_at_end = r"""
    ( # start group
        (
            (
                (O|o)ld|
                (N|n)ew|
                (R|r)evised|
                Comprehensive|
                Spanish|
                Philippine|
                National|
                Internal|
                Omnibus|
                State
            )
            \s+
        )*
        (
            (
                Coconut|
                Industry|
                Agrarian|
                Reform|
                Civil|
                Labor|
                Administrative|
                Corporation|
                Cooperative|
                Tax|
                Family|
                Fire|
                Flag|
                Heraldic|
                Insurance|
                Land|
                Agricultural|
                Transportation|
                Traffic|
                Building|
                Child|
                Youth|
                Forest|
                Local|
                Government|
                Meat|
                Inspection|
                Revenue|
                Election|
                Penal|
                Sanitation|
                Auditing|
                Tariff|
                Customs|
                Water|
                Environment|
                Intellectual|
                Real|
                Property|
                Responsibility
            )
            \s+
            (
                and
                \s+
            )?
        )+
        Code
    ) # end group
    """

    extension = r"""
    (
        \s+
        of
        \s+
        (
            (
                19[0-9][0-9]| # 1900 to 1999
                2[0-2][0-9][0-9] # 2000 to 2299
            )|
            (
                the
                \s+
                Philippines
            )
        )
    )?
    """

    formula = rf"""
    (?P<legal_code>
        (
            {code_at_end}
            {extension}
        )|
        (
            {code_at_start}
            {capitalized_text}
        )|
        (
            {special_acronyms}
        )
    )
    """
