from .base import StatutePatternsMethods


class AdministrativeMatter(StatutePatternsMethods):
    def __init__(self) -> None:
        base_text = self.statute_base_pattern(
            group_name="rule_am",
            first_word=r"""Adm(
                \.|
                in\.|
                inistrative
            )""",
            second_word=r"Matter",
            first_letter="A",
            second_letter="M",
            optional_number_keyword=self.optional_number_keyword,
        )

        digit = rf"(?P<AM_digit>[\w-]+)"

        self.formula = rf"""
        ( # e.g. Administrative Matter (AM) No. 242
            \b{base_text}
            \s*{digit}
        )
        """


class BarMatter(StatutePatternsMethods):
    def __init__(self) -> None:
        base_text = self.statute_base_pattern(
            group_name="rule_bm",
            first_word=r"Bar",
            second_word=r"Matter",
            first_letter="B",
            second_letter="M",
            optional_number_keyword=self.optional_number_keyword,
        )

        digit = rf"(?P<BM_digit>{self.digit_format})"

        self.formula = rf"""
        ( # e.g. Bar Matter (AM) No. 242
            \b{base_text}
            \s*{digit}
        )
        """


class ResolutionEnBanc(StatutePatternsMethods):
    def __init__(self) -> None:
        version_one = rf"""
        (
            Court
            \s+
            En
            \s+
            Banc
            \s+
            Resolution
        )
        """

        version_two = rf"""
        (
            Resolution
            \s+
            [o|O]f
            \s+
            [t|T]he
            \s+
            Court
            \s+
            En
            \s+
            Banc
        )
        """

        digit = rf"(?P<RESO_digit>[\w-]+)"

        self.formula = rf"""
        ( # e.g. Court En Banc Resolution dated 10-15-1991
            \b
            (?P<rule_reso>{version_one}|{version_two}
            )
            \s+
            [D|d]ated
            \s*{digit}
        )
        """
